b12n.swiza.interop.core


declared-methodsclj

(declared-methods clazz)

List out the declared methods of a given class

Examples: (declared-methods java.util.UUID) (declared-methods java.lang.String)

List out the declared methods of a given class

Examples:
(declared-methods java.util.UUID)
(declared-methods java.lang.String)
sourceraw docstring

declared-namesclj

(declared-names clazz)

Extract the unique function names from a given class.

Example: (declared-names java.util.UUID)

Extract the unique function names from a given class.

Example:
(declared-names java.util.UUID)
sourceraw docstring

java-methodsclj

(java-methods object)
source

jmethodsclj

(jmethods object
          &
          [{:keys [show-public? short-format? show-getter? show-setter?
                   show-private?]
            :or {show-public? true
                 short-format? true
                 show-getter? false
                 show-setter? false
                 show-private? false}}])
source

(print-methods clazz)

Print the method of a given Java class.

Examples: (print-methods java.util.UUID) ;; see your REPL (print-methods java.lang.String)

Print the method of a given Java class.

Examples:
(print-methods java.util.UUID) ;; see your REPL
(print-methods java.lang.String)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries