(declared-methods clazz)List out the declared methods of a given class
Examples: (declared-methods java.util.UUID) (declared-methods java.lang.String)
List out the declared methods of a given class Examples: (declared-methods java.util.UUID) (declared-methods java.lang.String)
(declared-names clazz)Extract the unique function names from a given class.
Example: (declared-names java.util.UUID)
Extract the unique function names from a given class. Example: (declared-names java.util.UUID)
(jmethods object
&
[{:keys [show-public? short-format? show-getter? show-setter?
show-private?]
:or {show-public? true
short-format? true
show-getter? false
show-setter? false
show-private? false}}])(print-methods clazz)Print the method of a given Java class.
Examples: (print-methods java.util.UUID) ;; see your REPL (print-methods java.lang.String)
Print the method of a given Java class. Examples: (print-methods java.util.UUID) ;; see your REPL (print-methods java.lang.String)
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |